@@ -14,7 +14,7 @@
 //!
 //! The Merkle distributor program and SDK is distributed under the GPL v3.0 license.
 
-use anchor_lang::prelude::*;
+use anchor_lang::{prelude::*, solana_program::pubkey::PUBKEY_BYTES};
 use anchor_spl::token::{self, Mint, Token, TokenAccount};
 use vipers::prelude::*;
 
@@ -156,6 +156,7 @@ pub struct NewDistributor<'info> {
             base.key().to_bytes().as_ref()
         ],
         bump,
+        space = 8 + MerkleDistributor::LEN,
         payer = payer
     )]
     pub distributor: Account<'info, MerkleDistributor>,
@@ -188,6 +189,7 @@ pub struct Claim<'info> {
             distributor.key().to_bytes().as_ref()
         ],
         bump,
+        space = 8 + ClaimStatus::LEN,
         payer = payer
     )]
     pub claim_status: Account<'info, ClaimStatus>,
@@ -238,6 +240,10 @@ pub struct MerkleDistributor {
     pub num_nodes_claimed: u64,
 }
 
+impl MerkleDistributor {
+    pub const LEN: usize = PUBKEY_BYTES + 1 + 32 + PUBKEY_BYTES + 8 * 4;
+}
+
 /// Holds whether or not a claimant has claimed tokens.
 ///
 /// TODO: this is probably better stored as the node that was verified.
@@ -254,6 +260,10 @@ pub struct ClaimStatus {
     pub amount: u64,
 }
 
+impl ClaimStatus {
+    pub const LEN: usize = 1 + PUBKEY_BYTES + 8 + 8;
+}
+
 /// Emitted when tokens are claimed.
 #[event]
 pub struct ClaimedEvent {
